==> zio-aws-macie2_2.12-5.17.126.2-sources.jar: zio/aws/macie2/model/ListJobsFilterTerm.scala <==
package zio.aws.macie2.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.aws.macie2.model.primitives.__string
import scala.jdk.CollectionConverters._
final case class ListJobsFilterTerm(
    comparator: Option[zio.aws.macie2.model.JobComparator] = None,
    key: Option[zio.aws.macie2.model.ListJobsFilterKey] = None,
    values: Option[Iterable[__string]] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.macie2.model.ListJobsFilterTerm = {
    import ListJobsFilterTerm.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.macie2.model.ListJobsFilterTerm
      .builder()
      .optionallyWith(comparator.map(value => value.unwrap))(_.comparator)
      .optionallyWith(key.map(value => value.unwrap))(_.key)
      .optionallyWith(
        values.map(value =>
          value.map { item =>
            __string.unwrap(item): java.lang.String
          }.asJavaCollection
        )
      )(_.values)
      .build()
  }
  def asReadOnly: zio.aws.macie2.model.ListJobsFilterTerm.ReadOnly =
    zio.aws.macie2.model.ListJobsFilterTerm.wrap(buildAwsValue())
}
object ListJobsFilterTerm {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.macie2.model.ListJobsFilterTerm
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.macie2.model.ListJobsFilterTerm =
      zio.aws.macie2.model.ListJobsFilterTerm(
        comparator.map(value => value),
        key.map(value => value),
        values.map(value => value)
      )
    def comparator: Option[zio.aws.macie2.model.JobComparator]
    def key: Option[zio.aws.macie2.model.ListJobsFilterKey]
    def values: Option[List[__string]]
    def getComparator: ZIO[Any, AwsError, zio.aws.macie2.model.JobComparator] =
      AwsError.unwrapOptionField("comparator", comparator)
    def getKey: ZIO[Any, AwsError, zio.aws.macie2.model.ListJobsFilterKey] =
      AwsError.unwrapOptionField("key", key)
    def getValues: ZIO[Any, AwsError, List[__string]] =
      AwsError.unwrapOptionField("values", values)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.macie2.model.ListJobsFilterTerm
  ) extends zio.aws.macie2.model.ListJobsFilterTerm.ReadOnly {
    override val comparator: Option[zio.aws.macie2.model.JobComparator] = scala
      .Option(impl.comparator())
      .map(value => zio.aws.macie2.model.JobComparator.wrap(value))
    override val key: Option[zio.aws.macie2.model.ListJobsFilterKey] = scala
      .Option(impl.key())
      .map(value => zio.aws.macie2.model.ListJobsFilterKey.wrap(value))
    override val values: Option[List[__string]] = scala
      .Option(impl.values())
      .map(value =>
        value.asScala.map { item =>
          zio.aws.macie2.model.primitives.__string(item)
        }.toList
      )
  }
  def wrap(
      impl: software.amazon.awssdk.services.macie2.model.ListJobsFilterTerm
  ): zio.aws.macie2.model.ListJobsFilterTerm.ReadOnly = new Wrapper(impl)
}

==> zio-aws-macie2_2.12-5.17.149.1-sources.jar: zio/aws/macie2/model/ListJobsFilterTerm.scala <==
package zio.aws.macie2.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.aws.macie2.model.primitives.__string
import scala.jdk.CollectionConverters._
final case class ListJobsFilterTerm(
    comparator: Option[zio.aws.macie2.model.JobComparator] = None,
    key: Option[zio.aws.macie2.model.ListJobsFilterKey] = None,
    values: Option[Iterable[__string]] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.macie2.model.ListJobsFilterTerm = {
    import ListJobsFilterTerm.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.macie2.model.ListJobsFilterTerm
      .builder()
      .optionallyWith(comparator.map(value => value.unwrap))(_.comparator)
      .optionallyWith(key.map(value => value.unwrap))(_.key)
      .optionallyWith(
        values.map(value =>
          value.map { item =>
            item: java.lang.String
          }.asJavaCollection
        )
      )(_.values)
      .build()
  }
  def asReadOnly: zio.aws.macie2.model.ListJobsFilterTerm.ReadOnly =
    zio.aws.macie2.model.ListJobsFilterTerm.wrap(buildAwsValue())
}
object ListJobsFilterTerm {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.macie2.model.ListJobsFilterTerm
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.macie2.model.ListJobsFilterTerm =
      zio.aws.macie2.model.ListJobsFilterTerm(
        comparator.map(value => value),
        key.map(value => value),
        values.map(value => value)
      )
    def comparator: Option[zio.aws.macie2.model.JobComparator]
    def key: Option[zio.aws.macie2.model.ListJobsFilterKey]
    def values: Option[List[__string]]
    def getComparator: ZIO[Any, AwsError, zio.aws.macie2.model.JobComparator] =
      AwsError.unwrapOptionField("comparator", comparator)
    def getKey: ZIO[Any, AwsError, zio.aws.macie2.model.ListJobsFilterKey] =
      AwsError.unwrapOptionField("key", key)
    def getValues: ZIO[Any, AwsError, List[__string]] =
      AwsError.unwrapOptionField("values", values)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.macie2.model.ListJobsFilterTerm
  ) extends zio.aws.macie2.model.ListJobsFilterTerm.ReadOnly {
    override val comparator: Option[zio.aws.macie2.model.JobComparator] = scala
      .Option(impl.comparator())
      .map(value => zio.aws.macie2.model.JobComparator.wrap(value))
    override val key: Option[zio.aws.macie2.model.ListJobsFilterKey] = scala
      .Option(impl.key())
      .map(value => zio.aws.macie2.model.ListJobsFilterKey.wrap(value))
    override val values: Option[List[__string]] = scala
      .Option(impl.values())
      .map(value =>
        value.asScala.map { item =>
          item: __string
        }.toList
      )
  }
  def wrap(
      impl: software.amazon.awssdk.services.macie2.model.ListJobsFilterTerm
  ): zio.aws.macie2.model.ListJobsFilterTerm.ReadOnly = new Wrapper(impl)
}
